[tor-commits] [stem/master] Changing descriptor archive links from Metrics to CollecTor

atagar at torproject.org atagar at torproject.org
Wed Jun 4 15:54:35 UTC 2014


commit a54d6430f802c270f70ee9cf850a34ec67245f02
Author: Damian Johnson <atagar at torproject.org>
Date:   Wed Jun 4 08:46:35 2014 -0700

    Changing descriptor archive links from Metrics to CollecTor
    
    Karsten just released CollecTor, a site that's replacing the Metrics archive.
    Adjusting our links...
    
      https://lists.torproject.org/pipermail/tor-dev/2014-June/006942.html
---
 docs/change_log.rst                          |    2 +-
 docs/tutorials/mirror_mirror_on_the_wall.rst |    4 ++--
 stem/descriptor/__init__.py                  |    2 +-
 stem/descriptor/extrainfo_descriptor.py      |    8 +++++---
 stem/descriptor/networkstatus.py             |    9 ++++++---
 stem/descriptor/server_descriptor.py         |   12 ++++++++----
 6 files changed, 23 insertions(+), 14 deletions(-)

diff --git a/docs/change_log.rst b/docs/change_log.rst
index cc68644..58fca66 100644
--- a/docs/change_log.rst
+++ b/docs/change_log.rst
@@ -60,7 +60,7 @@ among numerous other improvements and fixes.
   * Added `support for CIRC_BW events <api/response.html#stem.response.events.CircuitBandwidthEvent>`_ (:spec:`6f2919a`)
   * Added `support for CELL_STATS events <api/response.html#stem.response.events.CellStatsEvent>`_ (:spec:`6f2919a`)
   * Added `support for TB_EMPTY events <api/response.html#stem.response.events.TokenBucketEmptyEvent>`_ (:spec:`6f2919a`)
-  * Added `support for HS_DESC events <api/response.html#stem.response.events.HSDescEvent>`_ (:spec:`a67ac4d`, :trac:`10807`)
+  * Added `support for HS_DESC events <api/response.html#stem.response.events.HSDescEvent>`_ (:trac:`10807`, :spec:`a67ac4d`)
   * Changed :func:`~stem.control.Controller.get_network_status` and :func:`~stem.control.Controller.get_network_statuses` to provide :class:`~stem.descriptor.router_status_entry.RouterStatusEntryMicroV3` if Tor is using microdescriptors (:trac:`7646`)
   * The :func:`~stem.connection.connect_port` and :func:`~stem.connection.connect_socket_file` didn't properly mark the Controller it returned as being authenticated, causing event listening among other things to fail
   * The :func:`~stem.control.Controller.add_event_listener` method couldn't accept event types that Stem didn't already recognize
diff --git a/docs/tutorials/mirror_mirror_on_the_wall.rst b/docs/tutorials/mirror_mirror_on_the_wall.rst
index a5ba5e6..0db54c3 100644
--- a/docs/tutorials/mirror_mirror_on_the_wall.rst
+++ b/docs/tutorials/mirror_mirror_on_the_wall.rst
@@ -64,8 +64,8 @@ Listing the current relays in the Tor network is as easy as...
 Where can I get past descriptors?
 ---------------------------------
 
-Descriptor archives are available on `Tor's metrics site
-<https://metrics.torproject.org/data.html>`_. These archives can be read with
+Descriptor archives are available from `CollecTor
+<https://collector.torproject.org/>`_. These archives can be read with
 the `DescriptorReader <../api/descriptor/reader.html>`_...
 
 ::
diff --git a/stem/descriptor/__init__.py b/stem/descriptor/__init__.py
index 4270cb9..887ab5b 100644
--- a/stem/descriptor/__init__.py
+++ b/stem/descriptor/__init__.py
@@ -87,7 +87,7 @@ def parse_file(descriptor_file, descriptor_type = None, validate = True, documen
   tries to determine the descriptor type based on the following...
 
   * The @type annotation on the first line. These are generally only found in
-    the `descriptor archives <https://metrics.torproject.org>`_.
+    the `CollecTor archives <https://collector.torproject.org/formats.html#relay-descriptors>`_.
 
   * The filename if it matches something from tor's data directory. For
     instance, tor's 'cached-descriptors' contains server descriptors.
diff --git a/stem/descriptor/extrainfo_descriptor.py b/stem/descriptor/extrainfo_descriptor.py
index da81567..72bc672 100644
--- a/stem/descriptor/extrainfo_descriptor.py
+++ b/stem/descriptor/extrainfo_descriptor.py
@@ -14,13 +14,15 @@ usage statistics. Tor clients cannot request these documents for bridges.
 
 Extra-info descriptors are available from a few sources...
 
-* if you have 'DownloadExtraInfo 1' in your torrc...
+* If you have 'DownloadExtraInfo 1' in your torrc...
 
  * control port via 'GETINFO extra-info/digest/\*' queries
  * the 'cached-extrainfo' file in tor's data directory
 
-* tor metrics, at https://metrics.torproject.org/data.html
-* directory authorities and mirrors via their DirPort
+* Archived descriptors provided by CollecTor
+  (https://collector.torproject.org/).
+
+* Directory authorities and mirrors via their DirPort.
 
 **Module Overview:**
 
diff --git a/stem/descriptor/networkstatus.py b/stem/descriptor/networkstatus.py
index 6cf0880..2310683 100644
--- a/stem/descriptor/networkstatus.py
+++ b/stem/descriptor/networkstatus.py
@@ -5,9 +5,12 @@
 Parsing for Tor network status documents. This supports both the v2 and v3
 dir-spec. Documents can be obtained from a few sources...
 
-* the 'cached-consensus' file in tor's data directory
-* tor metrics, at https://metrics.torproject.org/data.html
-* directory authorities and mirrors via their DirPort
+* The 'cached-consensus' file in Tor's data directory.
+
+* Archived descriptors provided by CollecTor
+  (https://collector.torproject.org/).
+
+* Directory authorities and mirrors via their DirPort.
 
 ... and contain the following sections...
 
diff --git a/stem/descriptor/server_descriptor.py b/stem/descriptor/server_descriptor.py
index 9416582..78e8741 100644
--- a/stem/descriptor/server_descriptor.py
+++ b/stem/descriptor/server_descriptor.py
@@ -6,10 +6,14 @@ Parsing for Tor server descriptors, which contains the infrequently changing
 information about a Tor relay (contact information, exit policy, public keys,
 etc). This information is provided from a few sources...
 
-* control port via 'GETINFO desc/\*' queries
-* the 'cached-descriptors' file in tor's data directory
-* tor metrics, at https://metrics.torproject.org/data.html
-* directory authorities and mirrors via their DirPort
+* The control port via 'GETINFO desc/\*' queries.
+
+* The 'cached-descriptors' file in Tor's data directory.
+
+* Archived descriptors provided by CollecTor
+  (https://collector.torproject.org/).
+
+* Directory authorities and mirrors via their DirPort.
 
 **Module Overview:**
 



More information about the tor-commits mailing list